.. image:: https://secure.travis-ci.org/demianbrecht/django_sanction.png?branch=master 
   :target: http://travis-ci.org/#!/demianbrecht/django_sanction


django_sanction is a Django wrapper for the sanction_ Python library. It allows
for rapid integration of OAuth 2.0 authentication, authorization and resource
access for clients.

Documentation can be found at readthedocs_.

.. _readthedocs: https://django-sanction.readthedocs.org/en/latest/
.. _sanction: https://github.com/demianbrecht/sanction
.. _`oauth2 spec`: http://www.google.ca/url?sa=t&rct=j&q=&esrc=s&source=web&cd=1&cad=rja&ved=0CGIQFjAA&url=http%3A%2F%2Ftools.ietf.org%2Fhtml%2Fietf-oauth-v2-30&ei=sBAtULqHDqPOiwK3zoDgDg&usg=AFQjCNGSdKvjocQl86fT8e-dp_53zeqR8g
